@@ -1,4 +1,4 @@
-//@line 39 "/buildbot/comm-central-linux-nightly/build/mail/base/content/mail-offline.js"
+//@line 39 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/mail-offline.js"
 
 var MailOfflineMgr = {
   offlineManager: null,
@@ -48,18 +48,15 @@ var MailOfflineMgr = {
     // changing the offline state with the networking service.
     if (!this.isOnline()) 
     {
-      var prefSendUnsentMessages = gPrefBranch.getIntPref("offline.send.unsent_messages");
-      // 0 == Ask, 1 == Always Send, 2 == Never Send
-      var sendUnsentMessages = (prefSendUnsentMessages == 0 && this.haveUnsentMessages() 
-                                && this.confirmSendUnsentMessages()) || prefSendUnsentMessages == 1;
-      this.offlineManager.goOnline(sendUnsentMessages, true /* playbackOfflineImapOperations */, msgWindow);
-
+      // We do the go online stuff in our listener for the online state change.
+      ioService.offline = false;
       // resume managing offline status now that we are going back online.
-      ioService.manageOfflineStatus = gPrefBranch.getBoolPref("offline.autoDetect");      
+      ioService.manageOfflineStatus = gPrefBranch.getBoolPref("offline.autoDetect");
     }
     else // going offline
     {
-      // Stop automatic management of the offline status since the user as decided to go offline.
+      // Stop automatic management of the offline status since the user has
+      // decided to go offline.
       ioService.manageOfflineStatus = false;
       var prefDownloadMessages = gPrefBranch.getIntPref("offline.download.download_messages");
       // 0 == Ask, 1 == Always Download, 2 == Never Download
@@ -219,8 +216,8 @@ var MailOfflineMgr = {
     {
       statusBarPanel.removeAttribute("offline");
       statusBarPanel.setAttribute("tooltiptext", this.offlineBundle.getString("onlineTooltip"));
-    }    
-  },   
+    }
+  },
 
   /**
    * private helper method called whenever we detect a change to the offline state
@@ -228,5 +225,15 @@ var MailOfflineMgr = {
   mailOfflineStateChanged: function (aGoingOffline)
   {
     this.updateOfflineUI(aGoingOffline);
+    if (!aGoingOffline)
+    {
+      let prefSendUnsentMessages = gPrefBranch.getIntPref("offline.send.unsent_messages");
+      // 0 == Ask, 1 == Always Send, 2 == Never Send
+      let sendUnsentMessages = (prefSendUnsentMessages == 0 &&
+                                this.haveUnsentMessages() &&
+                                this.confirmSendUnsentMessages()) ||
+                               prefSendUnsentMessages == 1;
+      this.offlineManager.goOnline(sendUnsentMessages, true, msgWindow);
+    }
   }
 };
